//This do-file presents a basic example (Mincer-Wage-Regression) of how to draw, merge and clean data from the SOEPlong panel!
//See the accompanying "SOEP_Manual.pdf" for more information!
//Author: Christian Kagerl, Chair of Labor Economics - Prof. Jahn, University of Bayreuth, Faculty of Law and Economics
//christian.kagerl@uni-bayreuth.de
//This version: June 19th, 2019

//After loading in datasets, you can use the command 'soephelp varname', install via
*net install soephelp, replace from(http://companion.soep.de/SOEPhelp/)

clear

global MY_IN_PATH   "Z:\SOEP_Daten\"         		   //The repository of the data after getting access to them via the chair
global MY_OUT_PATH  "Z:\your_name\"     	           //Folder (on the Z:\ drive!) where your created data sets, analysis, do-Files etc. should go

log using "$MY_OUT_PATH\soep_data_example.log", replace
set more off

//Extract data (the three forward slashes make the code more tractable while indicating to STATA that the command is one logical line)
//Data on samples and general information
use cid hid pid syear ///
	psample netto pop erstbefr sex phrf gebjahr ///
	using "$MY_IN_PATH\ppathl.dta" 
sort pid syear
save "$MY_OUT_PATH\temp_1.dta", replace
clear

//Data on general variables
use cid hid pid syear ///
	d11102ll x11105 d11101 d11104 d11108 d11109 ///
	e11101 e11102 i11110 y11101 l11101 l11102 ///
	using "$MY_IN_PATH\pequiv.dta"
sort pid syear
save "$MY_OUT_PATH\temp_2.dta", replace
clear

//Extract data from a different data set
use cid hid pid syear ///
	plh0263_h ///
	using "$MY_IN_PATH\pl.dta"
sort pid syear
save "$MY_OUT_PATH\temp_3.dta", replace
clear

//Data from yet another data set
use cid hid pid syear ///
	pgexpft pglabgro ///
	using "$MY_IN_PATH\pgen.dta"
sort pid syear
save "$MY_OUT_PATH\temp_4.dta", replace


//Merge the data sets together
merge 1:1 pid syear using "$MY_OUT_PATH\temp_1.dta", nogen keep(3)  //The last part eliminates all non-matched observations		 
merge 1:1 pid syear using "$MY_OUT_PATH\temp_2.dta", nogen keep(3)
merge 1:1 pid syear using "$MY_OUT_PATH\temp_3.dta", nogen keep(3)

save "$MY_OUT_PATH\your_soep_data.dta", replace

//Erase temporary files
forvalues i = 1(1)4 {
erase "$MY_OUT_PATH\temp_`i'.dta"
}

clear


//Cleaning the data according to your needs 
use "$MY_OUT_PATH\your_soep_data.dta"

*Private Households only
keep if pop == 1 | pop==2

*Throwing out first-time-respondents
*drop if erstbefr==syear

*'psample' allows you to restrict your data set to certain samples, 
*see https://paneldata.org/soep-core/data/ppathl/psample 

*Converting negative integers to missing values (for all variables)
mvdecode _all, mv(-8/-1)

*Only keep successful *individual* interviews
*see https://paneldata.org/soep-core/data/ppathl/netto or 'tab netto' for more information
drop if netto>19

*Restricting the sample to working-age population
rename d11101 age
drop if age<18 | age>65

*Restricting the sample to the period after German Reunification
keep if syear>1990

*Number of years of education
rename d11109 educ

*Creating a dummy for persons residing in city-states
gen city_state = (l11101==11 | l11101==2 | l11101==4)
replace city_state=. if l11101==.

*Dummy for East Germany
gen east = (l11102==2)
replace east=. if l11102==.

*Creating a dummy for trade union membership
gen union = (plh0263_h==1)
replace union=. if plh0263_h==.

//To generate more observations, the SOEP creates some variables that use imputed values.
*Using this to create a wage variable and adjusting it for inflation:
rename pglabgro wage                  //This (generated) variable measures Gross Labor Income
rename y11101 cpi                     //The index expresses prices in 2010 constant euros (see the Codebook for more details).
gen adj_wage = wage*cpi
gen ln_wage = ln(adj_wage)

*"pgexpft" measures the years of fulltime working experience
rename pgexpft exper
gen exper_sq = exper*exper


//You can then do a very basic Mincer-Wage-Regression with the SOEP-Data
drop if ln_wage==. | exper_sq==. | educ==. | union==. | east==. | city_state==.   //Restrict sample to the same number of observations.
desc
sum
xtset pid syear
xtreg ln_wage educ exper exper_sq union east city_state i.syear, fe cluster(pid)

//If you want a fully balanced panel
preserve
xtdescribe
tab syear
bysort pid: gen number_years = [_N]
tab number_years
keep if number_years == 7 //Maximum Value from the tab command in the line above
xtreg ln_wage educ exper exper_sq union east city_state i.syear, fe cluster(pid)
restore

save "$MY_OUT_PATH\mincer_example.dta", replace

log close
clear
